 
 
 
const colorPreview = document.getElementById('colorPreview');
const redSlider1 = document.getElementById('redSlider1');
const greenSlider1 = document.getElementById('greenSlider1');
const blueSlider1 = document.getElementById('blueSlider1');
const alphaSlider1 = document.getElementById('alphaSlider1');
const redSlider2 = document.getElementById('redSlider2');
const greenSlider2 = document.getElementById('greenSlider2');
const blueSlider2 = document.getElementById('blueSlider2');
const alphaSlider2 = document.getElementById('alphaSlider2');
const angleSlider = document.getElementById('angleSlider');
const modeButton = document.getElementById('modeButton'); 
const btnRandom = document.getElementById('btnRandom'); 
const angleDisplay = document.getElementById('angleDisplay'); 
const colorValues = document.getElementById('colorValues'); 

let isGradientMode = false; 

function randomColor() {
  const red1 = Math.floor(Math.random() * 256);
  const green1 = Math.floor(Math.random() * 256);
  const blue1 = Math.floor(Math.random() * 256);

  return `rgb(${red1}, ${green1}, ${blue1})`;
}

function updateColorPreview() {
  let color;
  if (isGradientMode) {
    const red2 = redSlider2.value;
    const green2 = greenSlider2.value;
    const blue2 = blueSlider2.value;
    const alpha2 = alphaSlider2.value;

    color = `linear-gradient(${angleSlider.value}deg, rgba(${redSlider1.value}, ${greenSlider1.value}, ${blueSlider1.value}, ${alphaSlider1.value}), rgba(${red2}, ${green2}, ${blue2}, ${alpha2}))`;
  } else {
    color = `rgba(${redSlider1.value}, ${greenSlider1.value}, ${blueSlider1.value}, ${alphaSlider1.value})`;
  }

  colorPreview.style.background = color;
  colorValues.innerText = `HEX: ${rgbToHex(redSlider1.value, greenSlider1.value, blueSlider1.value)}\nRGB: ${color}`;

  saveColorState();
}

function rgbToHex(r, g, b) {
  const hexR = Number(r).toString(16).padStart(2, '0');
  const hexG = Number(g).toString(16).padStart(2, '0');
  const hexB = Number(b).toString(16).padStart(2, '0');
  return `#${hexR}${hexG}${hexB}`;
}

function toggleMode() {
  isGradientMode = !isGradientMode; 

  const secondColorInputs = document.getElementById('secondColorInputs');
  secondColorInputs.style.display = isGradientMode ? 'block' : 'none';

  updateColorPreview();

  modeButton.innerText = isGradientMode ? '单色模式' : '渐变模式';
}

function saveColorState() {
  const colorState = {
    redSlider1Value: redSlider1.value,
    greenSlider1Value: greenSlider1.value,
    blueSlider1Value: blueSlider1.value,
    alphaSlider1Value: alphaSlider1.value,
    redSlider2Value: redSlider2.value,
    greenSlider2Value: greenSlider2.value,
    blueSlider2Value: blueSlider2.value,
    alphaSlider2Value: alphaSlider2.value,
    angleSliderValue: angleSlider.value,
    isGradientMode: isGradientMode
  };

  localStorage.setItem('colorState', JSON.stringify(colorState));
}

function loadColorState() {
  const savedColorState = localStorage.getItem('colorState');
  if (savedColorState) {
    const colorState = JSON.parse(savedColorState);

    redSlider1.value = colorState.redSlider1Value;
    greenSlider1.value = colorState.greenSlider1Value;
    blueSlider1.value = colorState.blueSlider1Value;
    alphaSlider1.value = colorState.alphaSlider1Value;
    redSlider2.value = colorState.redSlider2Value;
    greenSlider2.value = colorState.greenSlider2Value;
    blueSlider2.value = colorState.blueSlider2Value;
    alphaSlider2.value = colorState.alphaSlider2Value;
    angleSlider.value = colorState.angleSliderValue;
    isGradientMode = colorState.isGradientMode;

    toggleMode(); 
  }
}

function init() {
  loadColorState(); 
  updateColorPreview();

  modeButton.innerText = isGradientMode ? '单色模式' : '渐变模式';

  redSlider1.addEventListener('input', updateColorPreview);
  greenSlider1.addEventListener('input', updateColorPreview);
  blueSlider1.addEventListener('input', updateColorPreview);
  alphaSlider1.addEventListener('input', updateColorPreview);
  redSlider2.addEventListener('input', updateColorPreview);
  greenSlider2.addEventListener('input', updateColorPreview);
  blueSlider2.addEventListener('input', updateColorPreview);
  alphaSlider2.addEventListener('input', updateColorPreview);
  angleSlider.addEventListener('input', updateColorPreview);
  modeButton.addEventListener('click', toggleMode);
  btnRandom.addEventListener('click', () => {
    redSlider1.value = Math.floor(Math.random() * 256);
    greenSlider1.value = Math.floor(Math.random() * 256);
    blueSlider1.value = Math.floor(Math.random() * 256);
    alphaSlider1.value = Math.random().toFixed(2);
    redSlider2.value = Math.floor(Math.random() * 256);
    greenSlider2.value = Math.floor(Math.random() * 256);
    blueSlider2.value = Math.floor(Math.random() * 256);
    alphaSlider2.value = Math.random().toFixed(2);
    angleSlider.value = Math.floor(Math.random() * 361);
    updateColorPreview();
  });
}

init();

